package com.hh.hhomc.deviceui;

import static android.content.Context.BIND_AUTO_CREATE;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.IBinder;
import android.os.RemoteException;
import android.text.TextUtils;
import android.util.Log;

import com.hh.hhomc.MyApplication;
import com.kte.interfacesettings.aidl.ITools;

/**
 * Description: $
 *
 * @author xwh
 * time 2024/12/11
 **/
public class PDADeviceUI implements IDeviceUI{


    //用volatile关键字确保 instance 在多线程下的可见性
    private static volatile PDADeviceUI instance = null;

    //将构造方法私有化，禁止外部通过构造方法创建实例
    private PDADeviceUI() {
        Intent intent2 = new Intent("com.kte.interfacesettings.aidl");
        intent2.setPackage("com.kte.interfacesettings");
        MyApplication.getContext().bindService(intent2,connectionService,BIND_AUTO_CREATE);
    }



    //提供一个公共的访问方法，用于获取该类的唯一实例
    public static PDADeviceUI getInstance() {
        //如果instance为空，就进行实例化
        if (instance == null) {
            //保证多线程下只有一个线程进行实例化
            synchronized (PDADeviceUI.class) {
                //第二次判断，避免多线程下创建多个实例
                if (instance == null) {
                    instance = new PDADeviceUI();
                }
            }
        }
        return instance;
    }

    private ITools myAIDLService;

    private ServiceConnection connectionService = new ServiceConnection(){
        @Override
        public void onServiceConnected(ComponentName name, IBinder service) {
            myAIDLService = ITools.Stub.asInterface(service);
            if(myAIDLService !=null){
                Log.d("BaseActivity"," myAIDLService"+myAIDLService.toString()+" AIDL 连接成功");
            }
            Log.d("BaseActivity","AIDL 绑定成功");
        }

        @Override
        public void onServiceDisconnected(ComponentName name) {
            myAIDLService = null;
        }
    };




    @Override
    public void showNotification() {
        if(myAIDLService !=null){
            try {
                myAIDLService.setStatusBarDropEnable(true);
            } catch (RemoteException e) {

            }
        }
    }

    @Override
    public void hideNotification() {
        if(myAIDLService !=null){
            try {
                myAIDLService.setStatusBarDropEnable(false);
            } catch (RemoteException e) {

            }
        }
    }

    @Override
    public void showNavigationBar() {
        if(myAIDLService !=null){
            try {
                myAIDLService.setHomeEnable(true);
                myAIDLService.setBackEnable(true);
                myAIDLService.setRecentEnable(true);
            } catch (RemoteException e) {

            }
        }
    }

    @Override
    public void hideNavigationBar() {
        if(myAIDLService !=null){
            try {
                myAIDLService.setBackEnable(false);
                myAIDLService.setHomeEnable(false);
                myAIDLService.setRecentEnable(false);
            } catch (RemoteException e) {

            }
        }
    }

    @Override
    public void showFillLight() {

    }

    @Override
    public void hideFillLight() {

    }

    @Override
    public void reboot() {
        if(myAIDLService !=null){
            try {
                myAIDLService.rebootDevice();
            } catch (RemoteException e) {

            }
        }
    }

    @Override
    public void silenceInstall(String path, SilenceInstallSuccessListener listener) {
        if(myAIDLService !=null){
            try {
                myAIDLService.silentInstall(path,false);
                if(listener!=null){
                    listener.success(true);
                }
            } catch (RemoteException e) {
                if(listener!=null){
                    listener.success(false);
                }
            }
        }else{
            if(listener!=null){
                listener.success(false);
            }
        }

    }

    @Override
    public void silenceUnInstall(String packageName) {

    }

    @Override
    public void startAPP(String packageName) {
        if(TextUtils.isEmpty(packageName)){
            return;
        }
        Intent intent = MyApplication.getContext().getPackageManager().getLaunchIntentForPackage(packageName);
        try {
            if (intent != null) {
                MyApplication.getContext().startActivity(intent);
            } else {
                // 应用无法启动
            }
        }catch (Exception e){

        }
    }

}
