package com.hh.hhomc.utils;

import static com.hh.hhomc.BuildConfig.BASE_URL;
import static com.hh.hhomc.common.Constants.SERVER_ACTION.DOWNLOAD_LOG;

import android.text.TextUtils;

import com.common.lib_base.common.async.ThreadPoolManager;
import com.common.lib_base.utils.log.AppLogUtils;
import com.google.gson.JsonObject;
import com.hh.hhomc.MyApplication;
import com.hh.hhomc.http.HttpManager;
import com.hh.hhomc.services.BackgroundService;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;
import java.util.ArrayList;
import java.util.concurrent.Future;

import okhttp3.FormBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

/**
 * Description: $
 * @author xwh
 * time 2024/12/31
 **/
public class ConfigUtils {

    private static String mTAG = ConfigUtils.class.getName();
    private Future future;  //log 上传处理线程
    private volatile static ConfigUtils instance;

    public static ConfigUtils getInstance() {
        if (instance == null) {
            synchronized (ConfigUtils.class) {
                if (instance == null) {
                    instance = new ConfigUtils();

                }
            }
        }
        return instance;
    }

    public void requestConfig(OnResponseCallback callback) {
        if (future != null && !future.isDone()) {
            return;
        }
        future = ThreadPoolManager.getInstance().sumbitIOTask(new Runnable() {
            @Override
            public void run() {
                try {
                    FormBody formBody = new FormBody.Builder()
                            .add("sn", DeviceUtils.getDeviceSN() + "")
                            .add("token","2915ac041cb759bfdc4968d4fce1c437")
                            .build();
                    Request request = new Request.Builder()
                            .url("https://tx.hz-hanghui.com:8088/hanghui-server-platform/api/v1/hh/omc/device/config/query")
                            .post(formBody)
                            .build();
                    OkHttpClient client = HttpManager.getInstance(MyApplication.getContext()).getmOkHttpClient();

                    Response response = client.newCall(request).execute();
                    if (!response.isSuccessful()) {
                        if (callback != null) {
                            callback.onFailed("Unexpected code: " + response);
                        }
                        return;
                    }
                    String data = response.body().string();
                    if (TextUtils.isEmpty(data)) {
                        if (callback != null) {
                            callback.onFailed("data =null ");
                        }
                        return;
                    }
                    JSONObject jsonObject = new JSONObject(data);
                    int code = jsonObject.optInt("code");
                    if (code == 200) {
                        String jsonData = jsonObject.optString("data");
                        JSONObject jsonDataObject = new JSONObject(jsonData);
                        String url = jsonDataObject.optString("websocketSubscribeUrl");
                        if (!TextUtils.isEmpty(url)) {
                            if (callback != null) {
                                callback.onSuccess(url);
                            }
                            return;
                        } else {
                            if (callback != null) {
                                callback.onFailed("url = null");
                            }
                            return;
                        }
                    } else {
                        if (callback != null) {
                            callback.onFailed("code : " + code);
                        }
                        return;
                    }
                } catch (IOException e) {
                    if (callback != null) {
                        callback.onFailed("Error : " + e.toString());
                    }
                    return;
                } catch (JSONException e) {
                    if (callback != null) {
                        callback.onFailed("JSONException : " + e.toString());
                    }
                    return;
                }


            }
        });


    }


    public interface OnResponseCallback {

        public void onSuccess(String url);

        public void onFailed(String errMsg);
    }
}
